use std::{mem, thread};
use std::borrow::Borrow;
use std::num::NonZeroU32;
use std::rc::Rc;
use std::time::Duration;
use winit::event::{Event, KeyEvent, StartCause, WindowEvent};
use winit::event_loop::{ControlFlow, EventLoop};
use winit::keyboard::{Key, NamedKey};
use winit::window::WindowBuilder;

fn main() {
    let event_loop = EventLoop::new().unwrap();
    let window = Rc::new(WindowBuilder::new().build(&event_loop).unwrap());

    let mut context = None;
    let mut surface = None;

    event_loop
        .run(move |event, elwt| {
            elwt.set_control_flow(ControlFlow::Wait);

            match event {
                Event::NewEvents(StartCause::Init) => {
                    context = Some(softbuffer::Context::new(window.clone()).unwrap());
                    surface = Some(softbuffer::Surface::new(context.as_mut().unwrap(), window.clone()).unwrap());
                    // let s = objc2::rc::autoreleasepool(|_| {
                    //         softbuffer::Surface::new(context.as_mut().unwrap(), window.clone()).unwrap()
                    //     });
                    // surface = Some(s);
                }
                Event::WindowEvent {
                    event:
                    WindowEvent::CloseRequested
                    | WindowEvent::KeyboardInput {
                        event:
                        KeyEvent {
                            logical_key: Key::Named(NamedKey::Escape),
                            ..
                        },
                        ..
                    },
                    window_id,
                } if window_id == window.id() => {
                    println!("Set surface to None");
                    surface=None;

                    println!("Set context to None");
                    context=None;

                    println!("Calling exit");
                    elwt.exit();
                }
                _  => {}
            }
        })
        .unwrap();

    println!("Sleep 1");
    thread::sleep(Duration::from_secs(1));
}
